@@ -73,8 +73,7 @@ class Config:
     files: list[PathLike] = field(default_factory=list)
     project_root: Optional[PathLike] = None
     query: Optional[list[str]] = None
-    host: str = "127.0.0.1"
-    port: int = 8000
+    db_url: str = "http://127.0.0.1:8000"
     embedding_function: str = "SentenceTransformerEmbeddingFunction"  # This should fallback to whatever the default is.
     embedding_params: dict[str, Any] = field(default_factory=(lambda: {}))
     n_result: int = 1
@@ -95,6 +94,7 @@ class Config:
     )
     hnsw: dict[str, str | int] = field(default_factory=dict)
     chunk_filters: dict[str, list[str]] = field(default_factory=dict)
+    filetype_map: dict[str, list[str]] = field(default_factory=dict)
     encoding: str = "utf8"
     hooks: bool = False
 
@@ -105,8 +105,21 @@ class Config:
         """
         default_config = Config()
         db_path = config_dict.get("db_path")
-        host = config_dict.get("host") or "localhost"
-        port = config_dict.get("port") or 8000
+        db_url = config_dict.get("db_url")
+        if db_url is None:
+            host = config_dict.get("host")
+            port = config_dict.get("port")
+            if host is not None or port is not None:
+                # TODO: deprecate `host` and `port` in 0.7.0
+                host = host or "127.0.0.1"
+                port = port or 8000
+                db_url = f"http://{host}:{port}"
+                logger.warning(
+                    f'"host" and "port" are deprecated and will be removed in 0.7.0. Use "db_url" (eg. {db_url}).'
+                )
+            else:
+                db_url = "http://127.0.0.1:8000"
+
         if db_path is None:
             db_path = os.path.expanduser("~/.local/share/vectorcode/chromadb/")
         elif not os.path.isdir(db_path):
@@ -121,8 +134,7 @@ class Config:
                 "embedding_params": config_dict.get(
                     "embedding_params", default_config.embedding_params
                 ),
-                "host": host,
-                "port": port,
+                "db_url": db_url,
                 "db_path": db_path,
                 "db_log_path": os.path.expanduser(
                     config_dict.get("db_log_path", default_config.db_log_path)
@@ -145,6 +157,9 @@ class Config:
                 "chunk_filters": config_dict.get(
                     "chunk_filters", default_config.chunk_filters
                 ),
+                "filetype_map": config_dict.get(
+                    "filetype_map", default_config.filetype_map
+                ),
                 "encoding": config_dict.get("encoding", default_config.encoding),
             }
         )
@@ -172,22 +187,27 @@ class Config:
 
 
 def get_cli_parser():
+    __default_config = Config()
     shared_parser = argparse.ArgumentParser(add_help=False)
     chunking_parser = argparse.ArgumentParser(add_help=False)
     chunking_parser.add_argument(
-        "--overlap", "-o", type=float, help="Ratio of overlaps between chunks."
+        "--overlap",
+        "-o",
+        type=float,
+        default=__default_config.overlap_ratio,
+        help="Ratio of overlaps between chunks.",
     )
     chunking_parser.add_argument(
         "-c",
         "--chunk_size",
         type=int,
-        default=-1,
+        default=__default_config.chunk_size,
         help="Size of chunks (-1 for no chunking).",
     )
     chunking_parser.add_argument(
         "--encoding",
         type=str,
-        default="utf8",
+        default=__default_config.encoding,
         help="Encoding used by the files. See https://docs.python.org/3/library/codecs.html#standard-encodings for supported encodings. Use `_auto` for automatic encoding detection.",
     )
     shared_parser.add_argument(
@@ -262,10 +282,18 @@ def get_cli_parser():
     )
     query_parser.add_argument("query", nargs="+", help="Query keywords.")
     query_parser.add_argument(
-        "--multiplier", "-m", type=int, default=-1, help="Query multiplier."
+        "--multiplier",
+        "-m",
+        type=int,
+        default=__default_config.query_multiplier,
+        help="Query multiplier.",
     )
     query_parser.add_argument(
-        "-n", "--number", type=int, default=1, help="Number of results to retrieve."
+        "-n",
+        "--number",
+        type=int,
+        default=__default_config.n_result,
+        help="Number of results to retrieve.",
     )
     query_parser.add_argument(
         "--exclude", nargs="*", help="Files to exclude from query results."
@@ -281,7 +309,7 @@ def get_cli_parser():
         choices=list(i.value for i in QueryInclude),
         nargs="+",
         help="What to include in the final output.",
-        default=["path", "document"],
+        default=__default_config.include,
     )
 
     subparsers.add_parser("drop", parents=[shared_parser], help="Remove a collection.")
