@@ -19,9 +19,10 @@ from vectorcode import __version__
 from vectorcode.cli_utils import (
     CliAction,
     Config,
+    cleanup_path,
     config_logging,
     find_project_root,
-    load_config_file,
+    get_project_config,
     parse_cli_args,
 )
 from vectorcode.common import get_client, get_collection, try_server
@@ -36,14 +37,11 @@ logger = logging.getLogger(__name__)
 async def make_caches(project_root: str):
     assert os.path.isabs(project_root)
     if cached_project_configs.get(project_root) is None:
-        config_file = os.path.join(project_root, ".vectorcode", "config.json")
-        if not os.path.isfile(config_file):
-            config_file = None
-        cached_project_configs[project_root] = await load_config_file(config_file)
+        cached_project_configs[project_root] = await get_project_config(project_root)
     config = cached_project_configs[project_root]
     config.project_root = project_root
-    host, port = config.host, config.port
-    if not await try_server(host, port):  # pragma: nocover
+    db_url = config.db_url
+    if not await try_server(db_url):  # pragma: nocover
         raise ConnectionError(
             "Failed to find an existing ChromaDB server, which is a hard requirement for LSP mode!"
         )
@@ -114,7 +112,7 @@ async def execute_command(ls: LanguageServer, args: list[str]):
                 progress_token,
                 types.WorkDoneProgressBegin(
                     "VectorCode",
-                    message="Retrieving from VectorCode",
+                    message=f"Querying {cleanup_path(str(final_configs.project_root))}",
                 ),
             )
             final_results = []
